r45401 - in /trunk/libcommon-sense-perl: Changes MANIFEST META.json META.yml README debian/changelog debian/control debian/copyright sense.pm

angelabad-guest at users.alioth.debian.org angelabad-guest at users.alioth.debian.org
Tue Oct 6 09:28:06 UTC 2009


Author: angelabad-guest
Date: Tue Oct  6 09:28:01 2009
New Revision: 45401

URL: http://svn.debian.org/wsvn/pkg-perl/?sc=1&rev=45401
Log:
New upstream 2.01

Added:
    trunk/libcommon-sense-perl/META.json
      - copied unchanged from r45400, branches/upstream/libcommon-sense-perl/current/META.json
Modified:
    trunk/libcommon-sense-perl/Changes
    trunk/libcommon-sense-perl/MANIFEST
    trunk/libcommon-sense-perl/META.yml
    trunk/libcommon-sense-perl/README
    trunk/libcommon-sense-perl/debian/changelog
    trunk/libcommon-sense-perl/debian/control
    trunk/libcommon-sense-perl/debian/copyright
    trunk/libcommon-sense-perl/sense.pm

Modified: trunk/libcommon-sense-perl/Changes
URL: http://svn.debian.org/wsvn/pkg-perl/trunk/libcommon-sense-perl/Changes?rev=45401&op=diff
==============================================================================
--- trunk/libcommon-sense-perl/Changes (original)
+++ trunk/libcommon-sense-perl/Changes Tue Oct  6 09:28:01 2009
@@ -1,4 +1,8 @@
 Revision history for perl pragma common::sense.
+
+2.01  Mon Oct  5 17:01:48 CEST 2009
+	- add a FAQ section.
+	- use a more future-proof way to set the warning mask.
 
 2.0   Tue Sep  1 20:28:25 CEST 2009
 	- codename "fatality", now with big doses of... fatality.

Modified: trunk/libcommon-sense-perl/MANIFEST
URL: http://svn.debian.org/wsvn/pkg-perl/trunk/libcommon-sense-perl/MANIFEST?rev=45401&op=diff
==============================================================================
--- trunk/libcommon-sense-perl/MANIFEST (original)
+++ trunk/libcommon-sense-perl/MANIFEST Tue Oct  6 09:28:01 2009
@@ -6,3 +6,4 @@
 sense.pm
 t/00_load.t
 META.yml                                 Module meta-data (added by MakeMaker)
+META.json                                Module meta-data (added by MakeMaker)

Modified: trunk/libcommon-sense-perl/META.yml
URL: http://svn.debian.org/wsvn/pkg-perl/trunk/libcommon-sense-perl/META.yml?rev=45401&op=diff
==============================================================================
--- trunk/libcommon-sense-perl/META.yml (original)
+++ trunk/libcommon-sense-perl/META.yml Tue Oct  6 09:28:01 2009
@@ -9,9 +9,9 @@
       "version" : 1.4,
       "url" : "http://module-build.sourceforge.net/META-spec-v1.4.html"
    },
-   "generated_by" : "ExtUtils::MakeMaker version 6.50",
+   "generated_by" : "ExtUtils::MakeMaker version 6.54",
    "distribution_type" : "module",
-   "version" : "2.0",
+   "version" : "2.01",
    "name" : "common-sense",
    "author" : [],
    "license" : "unknown",

Modified: trunk/libcommon-sense-perl/README
URL: http://svn.debian.org/wsvn/pkg-perl/trunk/libcommon-sense-perl/README?rev=45401&op=diff
==============================================================================
--- trunk/libcommon-sense-perl/README (original)
+++ trunk/libcommon-sense-perl/README Tue Oct  6 09:28:01 2009
@@ -4,7 +4,7 @@
 SYNOPSIS
      use common::sense;
 
-     # roughly the same as, with much lower memory usage:
+     # supposed to be the same, with much lower memory usage, as:
      #
      # use strict qw(vars subs);
      # use feature qw(say state switch);
@@ -37,9 +37,10 @@
         as using "", so one would even have to write (at least for the time
         being):
 
-           @{ defined $var->[0] ? $var->[0] :  [] }
-
-        ... which nobody with a bit of common sense would consider writing.
+           @{ defined $var->[0] ? $var->[0] : [] }
+
+        ... which nobody with a bit of common sense would consider writing:
+        clear code is clearly something else.
 
         Curiously enough, sometimes perl is not so strict, as this works
         even with "use strict" in scope:
@@ -156,6 +157,12 @@
 
        "i wonder how it would be if joerg schilling wrote perl modules."
 
+    Adam Kennedy
+
+       "Very interesting, efficient, and potentially something I'd use all the time."
+       [...]
+       "So no common::sense for me, alas."
+
     H.Merijn Brand
 
        "Just one more reason to drop JSON::XS from my distribution list"
@@ -201,6 +208,71 @@
 
        How about quoting this: get a clue, you fucktarded amoeba.
 
+FREQUQNTLY ASKED QUESTIONS
+    Or frequently-come-up confusions.
+
+    Is this module meant to be serious?
+        Yes, we would have put it under the "Acme::" namespace otherwise.
+
+    But the manpage is written in a funny/stupid/... way?
+        This was meant to make it clear that our common sense is a
+        subjective thing and other people can use their own notions, taking
+        the steam out of anybody who might be offended (as some people are
+        always offended no matter what you do).
+
+        This was a failure.
+
+        But we hope the manpage still is somewhat entertaining even though
+        it explains boring rationale.
+
+    Why do you impose your conventions on my code?
+        For some reason people keep thinking that "common::sense" imposes
+        process-wide limits, even though the SYNOPSIS makes it clear that it
+        works like other similar modules - only on the scope that uses them.
+
+        So, no, we don't - nobody is forced to use this module, and using a
+        module that relies on common::sense does not impose anything on you.
+
+    Why do you think only your notion of common::sense is valid?
+        Well, we don't, and have clearly written this in the documentation
+        to every single release. We were just faster than anybody else
+        w.r.t. to grabbing the namespace.
+
+    But everybody knows that you have to use strict and use warnings, why do
+    you disable them?
+        Well, we don't do this either - we selectively disagree with the
+        usefulness of some warnings over others. This module is aimed at
+        experienced Perl programmers, not people migrating from other
+        languages who might be surprised about stuff such as "undef".
+
+        In fact, this module is considerably *more* strict than the
+        canonical "use strict; use warnings", as it makes all warnings fatal
+        in nature, so you can get away with as many things as with the
+        canonical approach.
+
+        This was not implemented in version 1.0 because of the daunting
+        number of warning categories and the difficulty in getting exactly
+        the set of warnings you wish (i.e. look at the SYNOPSIS in how
+        complicated it is to get a specific set of warnings - it is not
+        reasonable to put this into every module, the maintainance effort
+        would be enourmous).
+
+    But many modules "use strict" or "use warnings", so the memory savings
+    do not apply?
+        I am suddenly so sad.
+
+        But yes, that's true. Fortunately "common::sense" still uses only a
+        miniscule amount of RAM.
+
+    But it adds another dependency to your modules!
+        It's a fact, yeah. But it's trivial to install, most popular modules
+        have many more dependencies and we consider dependencies a good
+        thing - it leads to better APIs, more thought about interworking of
+        modules and so on.
+
+    But! But!
+        Yeah, we know.
+
 AUTHOR
      Marc Lehmann <schmorp at schmorp.de>
      http://home.schmorp.de/

Modified: trunk/libcommon-sense-perl/debian/changelog
URL: http://svn.debian.org/wsvn/pkg-perl/trunk/libcommon-sense-perl/debian/changelog?rev=45401&op=diff
==============================================================================
--- trunk/libcommon-sense-perl/debian/changelog (original)
+++ trunk/libcommon-sense-perl/debian/changelog Tue Oct  6 09:28:01 2009
@@ -1,8 +1,13 @@
-libcommon-sense-perl (2.0-2) UNRELEASED; urgency=low
+libcommon-sense-perl (2.01-1) unstable; urgency=low
 
+  [ Ryan Niebur ]
   * Update ryan52's email address
 
- -- Ryan Niebur <ryan at debian.org>  Fri, 25 Sep 2009 00:24:13 -0700
+  [ Angel Abad (Ikusnet SLL) ]
+  * New upstream release
+  * Add myself to Uploaders
+
+ -- Angel Abad (Ikusnet SLL) <angel at grupoikusnet.com>  Tue, 06 Oct 2009 11:27:47 +0200
 
 libcommon-sense-perl (2.0-1) unstable; urgency=low
 

Modified: trunk/libcommon-sense-perl/debian/control
URL: http://svn.debian.org/wsvn/pkg-perl/trunk/libcommon-sense-perl/debian/control?rev=45401&op=diff
==============================================================================
--- trunk/libcommon-sense-perl/debian/control (original)
+++ trunk/libcommon-sense-perl/debian/control Tue Oct  6 09:28:01 2009
@@ -2,9 +2,9 @@
 Section: perl
 Priority: optional
 Build-Depends: debhelper (>= 7)
-Build-Depends-Indep: perl
 Maintainer: Debian Perl Group <pkg-perl-maintainers at lists.alioth.debian.org>
-Uploaders: Ryan Niebur <ryan at debian.org>
+Uploaders: Ryan Niebur <ryan at debian.org>,
+ Angel Abad (Ikusnet SLL) <angel at grupoikusnet.com>
 Standards-Version: 3.8.3
 Homepage: http://search.cpan.org/dist/common-sense/
 Vcs-Svn: svn://svn.debian.org/pkg-perl/trunk/libcommon-sense-perl/
@@ -12,7 +12,7 @@
 
 Package: libcommon-sense-perl
 Architecture: all
-Depends: ${perl:Depends}, ${misc:Depends}
+Depends: ${misc:Depends}, ${perl:Depends}
 Description: module that implements some sane defaults for Perl programs
  common::sense implements some sane defaults for Perl programs, as defined by
  two typical (or not so typical - use your common sense) specimens of Perl

Modified: trunk/libcommon-sense-perl/debian/copyright
URL: http://svn.debian.org/wsvn/pkg-perl/trunk/libcommon-sense-perl/debian/copyright?rev=45401&op=diff
==============================================================================
--- trunk/libcommon-sense-perl/debian/copyright (original)
+++ trunk/libcommon-sense-perl/debian/copyright Tue Oct  6 09:28:01 2009
@@ -1,86 +1,19 @@
 Format-Specification:
     http://wiki.debian.org/Proposals/CopyrightFormat?action=recall&rev=196
-Upstream-Maintainer: Marc Lehmann <schmorp at schmorp.de> and Robin Redeker <elmex at ta-sa.org>
+Upstream-Maintainer: Marc Lehmann <schmorp at schmorp.de> and Robin Redeker <elmex at ta-sa.org>
 Upstream-Source: http://search.cpan.org/dist/common-sense/
 Upstream-Name: common-sense
 
 Files: *
-Copyright: Copyright 2009 Marc Lehmann and Robin Redeker
+Copyright: 2009, Marc Lehmann <schmorp at schmorp.de>
+ 2009, Robin Redeker, <elmex at ta-sa.org>
 License-Alias: Perl
 License: Artistic | GPL-1+
-X-Email:
-    From root at schmorp.de Sat Aug 22 13:08:49 2009
-    Delivered-To: ryan at debian.org
-    Received: by 10.140.248.2 with SMTP id v2cs115971rvh;
-            Sat, 22 Aug 2009 13:08:50 -0700 (PDT)
-    Received: by 10.223.6.23 with SMTP id 23mr1908412fax.89.1250971729199;
-            Sat, 22 Aug 2009 13:08:49 -0700 (PDT)
-    Return-Path: <root at schmorp.de>
-    Received: from mail.nethype.de (mail.nethype.de [78.47.73.129])
-            by mx.google.com with ESMTP id 7si5847011fxm.79.2009.08.22.13.08.48;
-            Sat, 22 Aug 2009 13:08:49 -0700 (PDT)
-    Received-SPF: pass (google.com: domain of root at schmorp.de designates 78.47.73.129 as permitted sender) client-ip=78.47.73.129;
-    Authentication-Results: mx.google.com; spf=pass (google.com: domain of root at schmorp.de designates 78.47.73.129 as permitted sender) smtp.mail=root at schmorp.de
-    Received: from [10.0.0.5] (helo=doom.schmorp.de)
-    	by mail.nethype.de with esmtp (Exim 4.69)
-    	(envelope-from <root at schmorp.de>)
-    	id 1MewtL-00010L-U3
-    	for ryan at debian.org; Sat, 22 Aug 2009 20:08:47 +0000
-    Received: from [10.0.0.1] (helo=cerebro.laendle)
-    	by doom.schmorp.de with esmtp (Exim 4.69)
-    	(envelope-from <root at schmorp.de>)
-    	id 1MewtL-0004Ft-OK
-    	for ryan at debian.org; Sat, 22 Aug 2009 20:08:47 +0000
-    Received: from root by cerebro.laendle with local (Exim 4.69)
-    	(envelope-from <root at schmorp.de>)
-    	id 1MewtL-0000wm-Na
-    	for ryan at debian.org; Sat, 22 Aug 2009 22:08:47 +0200
-    Date: Sat, 22 Aug 2009 22:08:47 +0200
-    From: Marc Lehmann <schmorp at schmorp.de>
-    To: Ryan Niebur <ryan at debian.org>
-    Subject: Re: copyright information for Debian for common::sense
-    Message-ID: <20090822200847.GB3562 at schmorp.de>
-    References: <20090820010308.GB14079 at jade.home>
-    MIME-Version: 1.0
-    Content-Type: text/plain; charset=us-ascii
-    Content-Disposition: inline
-    In-Reply-To: <20090820010308.GB14079 at jade.home>
-    X-PGP: "1024D/DA743396 1999-01-26 Marc Alexander Lehmann
-    	<schmorp at schmorp.de>       Key fingerprint = 475A FE9B D1D4 039E
-    	01AC  C217 A1E8 0270 DA74 3396"
-    Status: RO
-    Content-Length: 961
-    Lines: 26
-    .
-    On Wed, Aug 19, 2009 at 06:03:08PM -0700, Ryan Niebur <ryan at debian.org> wrote:
-    > I'm just curious about copyright/licensing info for common::sense. I
-    .
-    Ooops, I completely forgot to include a license - that was an oversight.
-    .
-    > know what you think of Debian's copyright requirements, so sorry for
-    > bugging you. If you could please just reply with the copyright
-    > statement I need, I would be very grateful.
-    .
-    Sure:
-    .
-    Authors: Marc Lehmann, Robin Redeker
-    Copyright 2009
-    License terms will be "This module is licensed under the same terms as perl
-    itself.",
-    but generally whatever is in LICENSE or COPYING (which I forgot to include).
-    .
-    Greetings,
-    .
-    -- 
-                    The choice of a       Deliantra, the free code+content MORPG
-          -----==-     _GNU_              http://www.deliantra.net
-          ----==-- _       generation
-          ---==---(_)__  __ ____  __      Marc Lehmann
-          --==---/ / _ \/ // /\ \/ /      pcg at goof.com
-          -=====/_/_//_/\_,_/ /_/\_\
 
 Files: debian/*
-Copyright: 2009, Ryan Niebur <ryan at debian.org>
+Copyright: 2009, Angel Abad (Ikusnet SLL) <angel at grupoikusnet.com>
+ 2009, Ryan Niebur <ryan at debian.org>
+ 2009, Ryan Niebur <ryanryan52 at gmail.com>
 License: Artistic | GPL-1+
 
 License: Artistic

Modified: trunk/libcommon-sense-perl/sense.pm
URL: http://svn.debian.org/wsvn/pkg-perl/trunk/libcommon-sense-perl/sense.pm?rev=45401&op=diff
==============================================================================
--- trunk/libcommon-sense-perl/sense.pm (original)
+++ trunk/libcommon-sense-perl/sense.pm Tue Oct  6 09:28:01 2009
@@ -6,7 +6,7 @@
 
  use common::sense;
 
- # roughly the same as, with much lower memory usage:
+ # supposed to be the same, with much lower memory usage, as:
  #
  # use strict qw(vars subs);
  # use feature qw(say state switch);
@@ -43,10 +43,10 @@
 using C<"">, so one would even have to write (at least for the time
 being):
 
-   @{ defined $var->[0] ? $var->[0] :  [] }
+   @{ defined $var->[0] ? $var->[0] : [] }
 
 ... which nobody with a bit of common sense would consider
-writing.
+writing: clear code is clearly something else.
 
 Curiously enough, sometimes perl is not so strict, as this works even with
 C<use strict> in scope:
@@ -141,9 +141,9 @@
 
 package common::sense;
 
-our $VERSION = '2.0';
-
-# paste this into pelr to find bitmask
+our $VERSION = '2.01';
+
+# paste this into perl to find bitmask
 
 # no warnings;
 # use warnings qw(FATAL closed threads internal debugging pack substr malloc unopened portable prototype
@@ -156,7 +156,7 @@
 
 sub import {
    # verified with perl 5.8.0, 5.10.0
-   ${^WARNING_BITS} = "\xfc\x3f\xf3\x00\x0f\xf3\xcf\xc0\xf3\xfc\x33\x03";
+   ${^WARNING_BITS} ^= ${^WARNING_BITS} ^ "\xfc\x3f\xf3\x00\x0f\xf3\xcf\xc0\xf3\xfc\x33\x03";
 
    # use strict vars subs
    $^H |= 0x00000600;
@@ -202,6 +202,12 @@
 
    "i wonder how it would be if joerg schilling wrote perl modules."
 
+Adam Kennedy
+
+   "Very interesting, efficient, and potentially something I'd use all the time."
+   [...]
+   "So no common::sense for me, alas."
+
 H.Merijn Brand
 
    "Just one more reason to drop JSON::XS from my distribution list"
@@ -247,6 +253,82 @@
 
    How about quoting this: get a clue, you fucktarded amoeba.
 
+=head1 FREQUQNTLY ASKED QUESTIONS
+
+Or frequently-come-up confusions.
+
+=over 4
+
+=item Is this module meant to be serious?
+
+Yes, we would have put it under the C<Acme::> namespace otherwise.
+
+=item But the manpage is written in a funny/stupid/... way?
+
+This was meant to make it clear that our common sense is a subjective
+thing and other people can use their own notions, taking the steam out
+of anybody who might be offended (as some people are always offended no
+matter what you do).
+
+This was a failure.
+
+But we hope the manpage still is somewhat entertaining even though it
+explains boring rationale.
+
+=item Why do you impose your conventions on my code?
+
+For some reason people keep thinking that C<common::sense> imposes
+process-wide limits, even though the SYNOPSIS makes it clear that it works
+like other similar modules - only on the scope that uses them.
+
+So, no, we don't - nobody is forced to use this module, and using a module
+that relies on common::sense does not impose anything on you.
+
+=item Why do you think only your notion of common::sense is valid?
+
+Well, we don't, and have clearly written this in the documentation to
+every single release. We were just faster than anybody else w.r.t. to
+grabbing the namespace.
+
+=item But everybody knows that you have to use strict and use warnings,
+why do you disable them?
+
+Well, we don't do this either - we selectively disagree with the
+usefulness of some warnings over others. This module is aimed at
+experienced Perl programmers, not people migrating from other languages
+who might be surprised about stuff such as C<undef>.
+
+In fact, this module is considerably I<more> strict than the canonical
+C<use strict; use warnings>, as it makes all warnings fatal in nature, so
+you can get away with as many things as with the canonical approach.
+
+This was not implemented in version 1.0 because of the daunting number
+of warning categories and the difficulty in getting exactly the set of
+warnings you wish (i.e. look at the SYNOPSIS in how complicated it is to
+get a specific set of warnings - it is not reasonable to put this into
+every module, the maintainance effort would be enourmous).
+
+=item But many modules C<use strict> or C<use warnings>, so the memory
+savings do not apply?
+
+I am suddenly so sad.
+
+But yes, that's true. Fortunately C<common::sense> still uses only a
+miniscule amount of RAM.
+
+=item But it adds another dependency to your modules!
+
+It's a fact, yeah. But it's trivial to install, most popular modules have
+many more dependencies and we consider dependencies a good thing - it
+leads to better APIs, more thought about interworking of modules and so
+on.
+
+=item But! But!
+
+Yeah, we know.
+
+=back
+
 =head1 AUTHOR
 
  Marc Lehmann <schmorp at schmorp.de>




More information about the Pkg-perl-cvs-commits mailing list